Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Struct StableContainerPayloadInfo

pub struct StableContainerPayloadInfo {
    pub type_name: String,
    pub variant: StablePayloadVariant,
    pub size: usize,
    pub alignment: usize,
}
Type-agnostic stable-container metadata parsed from a payload encoding.

Fields

type_name: String

Cross-process and cross-language stable type identity.

variant: StablePayloadVariant

Stable-container payload variant.

size: usize

Exact payload size in bytes.

alignment: usize

Advertised payload alignment in bytes.

Implementations

Source

impl StableContainerPayloadInfo

pub const ENCODING_ID: &'static str = STABLE_CONTAINER_ENCODING_ID

Native custom encoding id for stable-container payloads.

pub fn parse(encoding: &PayloadEncoding) -> Result<Self, UWireError>

Parses stable-container metadata from a payload encoding.

Errors

Returns an error if the encoding is not stable-container metadata or if the stable-container content type is malformed.

pub fn is_compatible_with<T>(&self) -> bool
where T: StablePayload,

Returns whether this metadata is compatible with local stable payload T.