pub struct StableContainerPayloadInfo {
pub type_name: String,
pub variant: StablePayloadVariant,
pub size: usize,
pub alignment: usize,
}Expand description
Type-agnostic stable-container metadata parsed from a payload encoding.
Fields
type_name: StringCross-process and cross-language stable type identity.
variant: StablePayloadVariantStable-container payload variant.
size: usizeExact payload size in bytes.
alignment: usizeAdvertised payload alignment in bytes.
Implementations
Sourceimpl StableContainerPayloadInfo
impl StableContainerPayloadInfo
Sourcepub const ENCODING_ID: &'static str = STABLE_CONTAINER_ENCODING_ID
pub const ENCODING_ID: &'static str = STABLE_CONTAINER_ENCODING_ID
Native custom encoding id for stable-container payloads.
Sourcepub fn parse(encoding: &PayloadEncoding) -> Result<Self, UWireError>
pub fn parse(encoding: &PayloadEncoding) -> Result<Self, UWireError>
Parses stable-container metadata from a payload encoding.
Errors
Returns an error if the encoding is not stable-container metadata or if the stable-container content type is malformed.
Sourcepub fn is_compatible_with<T>(&self) -> boolwhere
T: StablePayload,
pub fn is_compatible_with<T>(&self) -> boolwhere
T: StablePayload,
Returns whether this metadata is compatible with local stable payload T.